@@ -1,8 +1,8 @@
-"use strict"
+// eslint-disable-next-line node/no-unsupported-features/es-syntax
+import privateClassElements from "acorn-private-class-elements"
 
-const privateClassElements = require("acorn-private-class-elements")
-
-module.exports = function(Parser) {
+// eslint-disable-next-line node/no-unsupported-features/es-syntax
+export default function privateMethods(Parser) {
   const ExtendedParser = privateClassElements(Parser)
 
   return class extends ExtendedParser {
@@ -16,7 +16,7 @@ module.exports = function(Parser) {
     }
 
     parsePropertyName(prop) {
-      const isPrivate = this.options.ecmaVersion >= 8 && this._inClassMemberName && this.type == this.privateNameToken
+      const isPrivate = this.options.ecmaVersion >= 8 && this._inClassMemberName && this.type == this.privateNameToken && !prop.static
       this._inClassMemberName = false
       if (!isPrivate) return super.parsePropertyName(prop)
       return this.parsePrivateClassElementName(prop)
